@@ -1,4 +1,4 @@
-/* $Id: keyboard-drawing.c,v 1.37 2004/12/31 00:26:58 svu Exp $ */
+/* $Id: keyboard-drawing.c,v 1.39 2005/04/10 01:18:52 svu Exp $ */
 /*
  * keyboard-drawing.c: implementation of a gtk+ widget that is a drawing of
  * the keyboard of the default display
@@ -602,6 +602,14 @@ is_key_flipped (
         case GDK_KP_Subtract:
         case GDK_KP_Add:
         case GDK_KP_Enter:
+        case GDK_KP_Page_Up:
+        case GDK_KP_Page_Down:
+        case GDK_KP_Home:
+        case GDK_KP_End:
+        case GDK_KP_Left:
+        case GDK_KP_Right:
+        case GDK_KP_Up:
+        case GDK_KP_Down:
           return TRUE;
         }
 
@@ -1612,8 +1620,7 @@ keyboard_drawing_init (
 }
 
 GtkWidget *
-keyboard_drawing_new (
-  )
+keyboard_drawing_new (void)
 {
   return GTK_WIDGET (g_object_new (keyboard_drawing_get_type (), NULL));
 }
@@ -1633,8 +1640,7 @@ keyboard_drawing_class_init (
 }
 
 GType
-keyboard_drawing_get_type (
-  )
+keyboard_drawing_get_type (void)
 {
   static GType keyboard_drawing_type = 0;
 
